<?php

/**
 * @file blipfm.views.inc
 *
 * Provides blipfm data to views
 *
 * This file describes the blipfm table to the views module so that
 * views can be created based on blipfm data.
 */

/**
 * Implementation of hook_views_data()
 */
function blipfm_views_data() {
  // ----------------------------------------------------------------
  // blipfm table

  // Define the base group of this table. Fields that don't
  // have a group defined will go into this field by default.
  $data['blipfm']['table']['group']  = t('BlipFM');
  $data['blipfm']['table']['base'] = array(
    'field' => 'blipfm_id',
    'title' => t('BlipFM'),
    'help' => t('A BlipFM track'),
  );
  
  $data['blipfm']['blipfm_id'] = array(
    'title' => t('blipfm ID'),
    'help' => t('Auto-generated by the blipfm system.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => FALSE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
  );

  $data['blipfm']['created_time'] = array(
    'title' => t('Created time'),
    'help' => t("The time/date of a blip.fm track"), // The help that appears on the UI,
    'field' => array(
      'handler' => 'views_handler_field_date',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_date',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_date',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort_date',
    ),
  );
  $data['blipfm']['title'] = array(
    'title' => t('Title'),
    'help' => t("The title of a blip.fm track."),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
      'float' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['blipfm']['artist'] = array(
    'title' => t('Artist'),
    'help' => t("The artist of the blip.fm track."),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
      'float' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['blipfm']['url'] = array(
    'title' => t('Song URL'),
    'help' => t("The url of the blip.fm track."),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
      'float' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['blipfm']['message'] = array(
    'title' => t('Message'),
    'help' => t("The message associated with the blip.fm track."),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
      'float' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  return $data;

}

/**
 * Implementation of hook_views_plugin
 *
 */
function blipfm_views_plugins() {
  return array(
    'style' => array( //declare the blipfm_* style plugins
      'views_blipfm' => array(
        'title' => t('Blip.fm player'),
        'help' => t('Displays a swf player to play the audio playlist.'),
        'handler' => 'views_plugin_style_blipfm',
        'theme' => 'views-view-blipfm',
        'uses row plugin' => FALSE,
        'uses fields' => TRUE,
        'uses options' => TRUE,
        'type' => 'normal',
        'help topic' => 'style-blipfm',
      ),    
    ),
  );
} 





